Exception: ActionHook::Security::IPBlocking::BlockedRequestError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/actionhook/security/ip_blocking.rb

Overview

If the destination host is a domain name, we'll attempt to resolve each of the IP addresses that resolve the domain name and block the webhook based on the configuration.